summaryrefslogtreecommitdiffstats
path: root/packaging/installer
diff options
context:
space:
mode:
authorMansour Behabadi <57921115+ncmans@users.noreply.github.com>2019-12-20 07:06:37 +1100
committerAustin S. Hemmelgarn <austin@netdata.cloud>2019-12-19 15:06:37 -0500
commit4edc7e907e3285aa9801e8caf651450e4fd8d2be (patch)
tree04d9265c637c1edd2f45166b100ef845f00d6a5d /packaging/installer
parenta73d3b3ed2f8d8c03d69f385bee37d46c144d4f4 (diff)
Add anon tracking notice for installers (#7437)
* Show notice of anonymous data collection * Add DO_NOT_TRACK env var to docker run script * Add disable-telemetry option to kickstart-static64 * Check if DO_NOT_TRACK is set
Diffstat (limited to 'packaging/installer')
-rw-r--r--packaging/installer/README.md2
-rwxr-xr-xpackaging/installer/kickstart-static64.sh6
2 files changed, 6 insertions, 2 deletions
diff --git a/packaging/installer/README.md b/packaging/installer/README.md
index 30498d650b..ffde6fc6b3 100644
--- a/packaging/installer/README.md
+++ b/packaging/installer/README.md
@@ -106,7 +106,7 @@ This script installs Netdata at `/opt/netdata`.
Verify the integrity of the script with this:
```bash
-[ "8ad43ff960bf6f2487233682909f7a87" = "$(curl -Ss https://my-netdata.io/kickstart-static64.sh | md5sum | cut -d ' ' -f 1)" ] && echo "OK, VALID" || echo "FAILED, INVALID"
+[ "23e0f38dfb9d517be16393c3ed1f88bd" = "$(curl -Ss https://my-netdata.io/kickstart-static64.sh | md5sum | cut -d ' ' -f 1)" ] && echo "OK, VALID" || echo "FAILED, INVALID"
```
*It should print `OK, VALID` if the script is the one we ship.*
diff --git a/packaging/installer/kickstart-static64.sh b/packaging/installer/kickstart-static64.sh
index 72cd00b879..1111e0e24f 100755
--- a/packaging/installer/kickstart-static64.sh
+++ b/packaging/installer/kickstart-static64.sh
@@ -8,7 +8,8 @@
# --non-interactive do not wait for input
# --dont-start-it do not start netdata after install
# --stable-channel Use the stable release channel, rather than the nightly to fetch sources
# --local-files Use a manually provided tarball for the installation
#
# ---------------------------------------------------------------------------------------------------------------------
# library functions copied from packaging/installer/functions.sh
@@ -200,6 +201,9 @@ while [ -n "${1}" ]; do
RELEASE_CHANNEL="stable"
NETDATA_INSTALLER_OPTIONS="${NETDATA_INSTALLER_OPTIONS:+${NETDATA_INSTALLER_OPTIONS} }${1}"
shift 1
+ elif [ "${1}" = "--disable-telemetry" ]; then
+ NETDATA_INSTALLER_OPTIONS="${NETDATA_INSTALLER_OPTIONS:+${NETDATA_INSTALLER_OPTIONS} }${1}"
+ shift 1
elif [ "${1}" = "--local-files" ]; then
shift 1
if [ -z "${1}" ]; then
@@ -8,7 +8,8 @@
# --dont-start-it do not start netdata after install
# --stable-channel Use the stable release channel, rather than the nightly to fetch sources
-# --local-files Use a manually provided tarball for the installation
+# --disable-telemetry Opt-out of anonymous telemetry program
+# --local-files Use a manually provided tarball for the installation
#
# ---------------------------------------------------------------------------------------------------------------------